==> vaycore-0.5.1.tar.gz: lib/common/options.dart <==
import 'package:flutter/material.dart';
import 'package:vaycore/dartin.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-09
///

/// 组件配置
class VayCoreOptions {
  /// 调式模式
  bool isDebug;

  /// 屏幕适配对应的屏幕宽度（UI设计图的宽度）
  final double adapterWidth;

  /// 网络日志打印配置
  HttpLogOptions httpLog;

  /// 需要支持依赖注入的模块
  List<Module> modules;

  /// 国际化配置
  LocaleOptions locale;

  VayCoreOptions(
      {this.isDebug = false,
      this.adapterWidth = 375,
      this.httpLog,
      this.locale,
      this.modules}) {
    this.httpLog = this.httpLog ?? HttpLogOptions();
  }
}

/// 网络请求日志配置
class HttpLogOptions {
  /// 请求地址显示
  final bool request;

  /// 请求头显示
  final bool requestHeader;

  /// 请求体显示
  final bool requestBody;

  /// 响应头显示
  final bool responseHeader;

  /// 响应体显示
  final bool responseBody;

  /// 错误显示
  final bool error;

  /// 打印方式指定
  void Function(Object object) logPrint;

  HttpLogOptions({
    this.request = false,
    this.requestHeader = true,
    this.requestBody = true,
    this.responseHeader = false,
    this.responseBody = true,
    this.error = true,
    this.logPrint = print,
  });
}

/// 国际化配置
class LocaleOptions<F> {
  /// 默认国际化支持列表
  static const List<Locale> _DEFAULT_SUPPORT_LOCALES = [
    const Locale('zh', 'CN'),
    const Locale('en', 'US'),
  ];

  /// 语言支持列表
  final List<Locale> _supportLocales;

  /// 语言资源
  final Map<String, Map<F, dynamic>> _localizedValues;

  /// 当前的语言
  Locale _locale;

  LocaleOptions(
      {Locale locale,
      Map<String, Map<F, dynamic>> localizedValues,
      List<Locale> supportLocales})
      : this._locale = locale,
        this._localizedValues = localizedValues,
        this._supportLocales = supportLocales ?? _DEFAULT_SUPPORT_LOCALES;

  /// 设置当前语言，如果传入的参数为空，则使用默认的语言
  set locale(Locale locale) {
    _locale = locale ?? this._supportLocales.first;
  }

  /// 获取当前语言，如果未传值，则返回默认的语言
  get locale {
    if (this._locale == null) {
      this._locale = this._supportLocales.first;
    }
    return this._locale;
  }

  /// 获取当前配置的语言对应的资源表，如果找不到ID，则返回默认的资源表
  Map<F, dynamic> getLocalizedValueById(F ids) {
    Map<F, dynamic> value = _localizedValues[locale.languageCode];
    if (value == null || !value.containsKey(ids)) {
      value = _localizedValues[_supportLocales.first.languageCode];
    }
    return value;
  }

  /// 支持的语言列表
  List<Locale> get supportLocales => _supportLocales;

  /// 简化国际化回调处理
  ///
  /// ```
  /// MaterialApp(
  ///   ...
  ///   localeResolutionCallback:
  ///               (Locale locale, Iterable<Locale> supportedLocales) =>
  ///                   core.options.locale.buildLocaleResolutionCallback(
  ///                       localeModel.locale, locale, supportedLocales),
  /// )
  /// ```
  buildLocaleResolutionCallback(Locale storageLocale, Locale locale, Iterable<Locale> supportedLocales) {
    if (storageLocale != null) {
      //如果已经选定语言，则不跟随系统
      return storageLocale;
    } else {
      Locale resultLocale;
      // APP语言跟随系统语言，如果系统语言不是中文简体或美国英语，
      // 则默认使用支持列表的第一个语言
      if (supportedLocales.contains(locale)) {
        resultLocale = locale;
      } else {
        resultLocale = this.supportLocales.first;
      }
      this.locale = resultLocale;
      return resultLocale;
    }
  }
}

==> vaycore-0.5.2.tar.gz: lib/common/options.dart <==
import 'package:flutter/material.dart';
import 'package:vaycore/dartin.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-09
///

/// 组件配置
class VayCoreOptions {
  /// 调式模式
  bool isDebug;

  /// 屏幕适配对应的屏幕宽度（UI设计图的宽度）
  final double adapterWidth;

  /// 网络日志打印配置
  HttpLogOptions httpLog;

  /// 需要支持依赖注入的模块
  List<Module> modules;

  /// 国际化配置
  LocaleOptions locale;

  VayCoreOptions(
      {this.isDebug = false,
      this.adapterWidth = 375,
      this.httpLog,
      this.locale,
      this.modules}) {
    this.httpLog = this.httpLog ?? HttpLogOptions();
  }
}

/// 网络请求日志配置
class HttpLogOptions {
  /// 请求地址显示
  final bool request;

  /// 请求头显示
  final bool requestHeader;

  /// 请求体显示
  final bool requestBody;

  /// 响应头显示
  final bool responseHeader;

  /// 响应体显示
  final bool responseBody;

  /// 错误显示
  final bool error;

  /// 打印方式指定
  void Function(Object object) logPrint;

  HttpLogOptions({
    this.request = false,
    this.requestHeader = true,
    this.requestBody = true,
    this.responseHeader = false,
    this.responseBody = true,
    this.error = true,
    this.logPrint = print,
  });
}

/// 国际化配置
class LocaleOptions<F> {
  /// 默认国际化支持列表
  static const List<Locale> _DEFAULT_SUPPORT_LOCALES = [
    const Locale('zh', 'CN'),
    const Locale('en', 'US'),
  ];

  /// 语言支持列表
  final List<Locale> _supportLocales;

  /// 语言资源
  final Map<String, Map<F, dynamic>> _localizedValues;

  /// 当前的语言
  Locale _locale;

  LocaleOptions(
      {Locale locale,
      Map<String, Map<F, dynamic>> localizedValues,
      List<Locale> supportLocales})
      : this._locale = locale,
        this._localizedValues = localizedValues,
        this._supportLocales = supportLocales ?? _DEFAULT_SUPPORT_LOCALES;

  /// 设置当前语言，如果传入的参数为空，则使用默认的语言
  set locale(Locale locale) {
    _locale = locale ?? this._supportLocales.first;
  }

  /// 获取当前语言，如果未传值，则返回默认的语言
  get locale {
    if (this._locale == null) {
      this._locale = this._supportLocales.first;
    }
    return this._locale;
  }

  /// 获取当前配置的语言对应的资源表，如果找不到ID，则返回默认的资源表
  Map<F, dynamic> getLocalizedValueById(F ids) {
    Map<F, dynamic> value = _localizedValues[locale.languageCode];
    if (value == null || !value.containsKey(ids)) {
      value = _localizedValues[_supportLocales.first.languageCode];
    }
    return value;
  }

  /// 支持的语言列表
  List<Locale> get supportLocales => _supportLocales;

  /// 简化国际化回调处理
  ///
  /// ```
  /// MaterialApp(
  ///   ...
  ///   localeResolutionCallback:
  ///               (Locale locale, Iterable<Locale> supportedLocales) =>
  ///                   core.options.locale.buildLocaleResolutionCallback(
  ///                       localeModel.locale, locale, supportedLocales),
  /// )
  /// ```
  buildLocaleResolutionCallback(
      Locale storageLocale, Locale locale, Iterable<Locale> supportedLocales) {
    if (storageLocale != null) {
      //如果已经选定语言，则不跟随系统
      return storageLocale;
    } else {
      Locale resultLocale;
      // APP语言跟随系统语言，如果系统语言不是中文简体或美国英语，
      // 则默认使用支持列表的第一个语言
      if (supportedLocales.contains(locale)) {
        resultLocale = locale;
      } else {
        resultLocale = this.supportLocales.first;
      }
      this.locale = resultLocale;
      return resultLocale;
    }
  }
}
